pub enum KeyValueDataType {
Show 13 variants RegNone = 0, RegSZ = 1, RegExpandSZ = 2, RegBinary = 3, RegDWord = 4, RegDWordBigEndian = 5, RegLink = 6, RegMultiSZ = 7, RegResourceList = 8, RegFullResourceDescriptor = 9, RegResourceRequirementsList = 10, RegQWord = 11, RegFileTime = 16,
}
Possible data types of the data belonging to a [KeyValue]. https://docs.microsoft.com/en-us/windows/win32/sysinfo/registry-value-types

Variants



RegNone = 0

Data with no particular type



RegSZ = 1

A null-terminated string. This will be either a Unicode or an ANSI string, depending on whether you use the Unicode or ANSI functions.



RegExpandSZ = 2

A null-terminated Unicode string, containing unexpanded references to environment variables, such as “%PATH%”



RegBinary = 3

Binary data in any form



RegDWord = 4

A 4-byte numerical value



RegDWordBigEndian = 5

A 4-byte numerical value whose least significant byte is at the highest address

A Unicode string naming a symbolic link. This type is irrelevant to device and intermediate drivers



RegMultiSZ = 7

An array of null-terminated strings, terminated by another zero



RegResourceList = 8

A device driver’s list of hardware resources, used by the driver or one of the physical devices it controls, in the \ResourceMap tree



RegFullResourceDescriptor = 9

A list of hardware resources that a physical device is using, detected and written into the \HardwareDescription tree by the system



RegResourceRequirementsList = 10

A device driver’s list of possible hardware resources it or one of the physical devices it controls can use, from which the system writes a subset into the \ResourceMap tree



RegQWord = 11

A 64-bit number.



RegFileTime = 16

FILETIME data