Struct dfir_toolkit::registry::types::RegistryString
source · pub struct RegistryString(_);Trait Implementations
sourceimpl AsRef<str> for RegistryString
impl AsRef<str> for RegistryString
sourceimpl BinRead for RegistryString
impl BinRead for RegistryString
type Args = usize
type Args = usize
The type of arguments needed to be supplied in order to read this type, usually a tuple. Read more
sourcefn read_options<R: Read + Seek>(
reader: &mut R,
_options: &ReadOptions,
args: Self::Args
) -> BinResult<Self>
fn read_options<R: Read + Seek>( reader: &mut R, _options: &ReadOptions, args: Self::Args ) -> BinResult<Self>
Read the type from the reader
sourcefn read<R>(reader: &mut R) -> Result<Self, Error>where
R: Read + Seek,
fn read<R>(reader: &mut R) -> Result<Self, Error>where R: Read + Seek,
Read the type from the reader while assuming no arguments have been passed Read more
sourcefn read_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>where
R: Read + Seek,
fn read_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>where R: Read + Seek,
Read the type from the reader using the specified arguments
fn after_parse<R>( &mut self, _: &mut R, _: &ReadOptions, _: Self::Args ) -> Result<(), Error>where R: Read + Seek,
sourceimpl From<RegistryString> for String
impl From<RegistryString> for String
sourcefn from(value: RegistryString) -> Self
fn from(value: RegistryString) -> Self
Converts to this type from the input type.