Enum dfir_toolkit::registry::types::KeyValueDataType
source · pub enum KeyValueDataType {
Show 13 variants
RegNone,
RegSZ,
RegExpandSZ,
RegBinary,
RegDWord,
RegDWordBigEndian,
RegLink,
RegMultiSZ,
RegResourceList,
RegFullResourceDescriptor,
RegResourceRequirementsList,
RegQWord,
RegFileTime,
}Expand description
Possible data types of the data belonging to a [KeyValue].
https://docs.microsoft.com/en-us/windows/win32/sysinfo/registry-value-types
Variants
RegNone
Data with no particular type
RegSZ
A null-terminated string. This will be either a Unicode or an ANSI string, depending on whether you use the Unicode or ANSI functions.
RegExpandSZ
A null-terminated Unicode string, containing unexpanded references to environment variables, such as “%PATH%”
RegBinary
Binary data in any form
RegDWord
A 4-byte numerical value
RegDWordBigEndian
A 4-byte numerical value whose least significant byte is at the highest address
RegLink
A Unicode string naming a symbolic link. This type is irrelevant to device and intermediate drivers
RegMultiSZ
An array of null-terminated strings, terminated by another zero
RegResourceList
A device driver’s list of hardware resources, used by the driver or one of the physical devices it controls, in the \ResourceMap tree
RegFullResourceDescriptor
A list of hardware resources that a physical device is using, detected and written into the \HardwareDescription tree by the system
RegResourceRequirementsList
A device driver’s list of possible hardware resources it or one of the physical devices it controls can use, from which the system writes a subset into the \ResourceMap tree
RegQWord
A 64-bit number.
RegFileTime
FILETIME data